/*******************************************************************************
* File Name: main.c
*
* Version: 2.0
*
* Description:
*  This is source code for the example of the Power Management API, which is
*  part of the cy_boot component. This project demonstrates the Hibernate low
*  power mode usage for PSoC 3/5LP devices.
*
********************************************************************************
* Copyright 2012-2014, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>


/*******************************************************************************
* Function Name: WakeupIsr
********************************************************************************
*
* Summary:
*  The Interrupt Service Routine for wakeup event.
*
* Parameters:  
*  None
*
* Return:
*  None
*
*******************************************************************************/
CY_ISR(WakeupIsr)
{
    /* Turn on LED to indicate Active mode */
    LED_P1_2_Write(1u);

    /* Clears active interrupt on the port */    
    pinWakeup_P0_2_ClearInterrupt();
}


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Main function performs following functions:
*   1. Turns LED1 on and enable global interrupts
*   2. Starts Character LCD component and displays project's information
*   3. Starts Interrupt component
*   4. The following steps are taken in the infinite loop:
*       5.1. The delay is made for visibility.
*       5.2. Prepare Character LCD component for the Hibernate mode.
*       5.3. Turn off LED1 to indicate Hibernate mode.
*       5.4. Prepare system clocks for the Hibernate mode.
*       5.5. Switch to the Hibernate Mode.
*       5.6. Wake up to the Active mode.
*       5.7. Turn on LED1 to indicate Active mode.
*       5.8. Restore clocks' configuration.
*       5.9. Prepare Character LCD component for the Active mode.
*       5.10. Go to the 5.1.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main()
{
    CyGlobalIntEnable;
    
    CyWdtStart(CYWDT_1024_TICKS,CYWDT_LPMODE_DISABLED);

    /* Turn on LED to indicate Active mode */
    LED_P1_2_Write(1u);

    /* Print example information */
    LCD_Start();
    LCD_Position(0u,0u);
    LCD_PrintString("PM API:Hibernate");
    
    /* Clear and start interrupt */    
    pinWakeup_P0_2_ClearInterrupt();
    ISR_StartEx(WakeupIsr);
    
    for(;;)
    {
        /* Make a delay for visibility */
        CyDelay(1000u);

        /* Prepare Character LCD component for the Sleep mode */
        LCD_Sleep();
        
        /* Turn off LED to indicate Hibernate mode */
        LED_P1_2_Write(0u);
        
        /* Prepare system clocks for the Hibernate mode */
        CyPmSaveClocks();
        CyWdtClear();
        /* Switch to the Hibernate Mode */
        CyPmHibernate();
        
        /* Restore clocks' configuration */
        CyPmRestoreClocks();       
        

        /***********************************************************************
        * Wake up the Character LCD component from the low power mode.
        * Configures DMA and enables the component for Active mode operation.
        ***********************************************************************/
        LCD_Wakeup();
    }
}


/* [] END OF FILE */
